@@ -197,6 +197,36 @@ get_prev_field (const char *line,
 }
 
 
+static char*
+tar_get_last_field (const char *line,
+		    int         start_from,
+		    int         field_n)
+{
+	const char *f_start, *f_end;
+	
+	line = line + start_from;
+        
+	f_start = line;
+	while ((*f_start == ' ') && (*f_start != *line))
+		f_start++;
+	f_end = f_start;
+
+	while ((field_n > 0) && (*f_end != 0)) {
+		if (*f_end == ' ') {
+			field_n--;
+			if (field_n != 0) {
+				while ((*f_end == ' ') && (*f_end != *line))
+					f_end++;
+				f_start = f_end;
+			}
+		} else
+			f_end++;
+	}
+	
+	return g_strdup (f_start);
+}
+
+
 static void
 process_line (char     *line, 
 	      gpointer  data)
@@ -225,7 +255,7 @@ process_line (char     *line,
 
 	/* Full path */
 
-	field_name = get_next_field (line, date_idx, 3);
+	field_name = tar_get_last_field (line, date_idx, 3);
 	fields = g_strsplit (field_name, " -> ", 2);
 
 	if (fields[1] == NULL) {
@@ -294,13 +324,25 @@ add_compress_arg (FRCommand *comm)
 static void
 begin_tar_command (FRCommand *comm)
 {
-	char *path = NULL;
+	char       *path = NULL;
+	const char *prev_path = NULL;
+	char       *temp = NULL;
+
+	/* In solaris gtar is present under /usr/sfw/bin */
+
+	prev_path = g_getenv ("PATH");
+	temp = g_strdup_printf ("PATH=%s:%s", prev_path, "/usr/sfw/bin");
+	putenv (temp);
 
 	path = g_find_program_in_path ("gtar");
 	if (path != NULL)
-		fr_process_begin_command (comm->process, "gtar");
+		fr_process_begin_command (comm->process, path);
 	else
 		fr_process_begin_command (comm->process, "tar");
+
+	temp = g_strdup_printf ("PATH=%s", prev_path);
+	putenv (temp);
+
 	g_free (path);
 }
 
